@@ -3,10 +3,10 @@
  *  Module    : tin.h
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2005-06-30
+ *  Updated   : 2006-01-10
  *  Notes     : #include files, #defines & struct's
  *
- * Copyright (c) 1997-2005 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1997-2006 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -204,9 +204,9 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 #	include <sys/times.h>
 #endif /* HAVE_SYS_TIMES_H */
 
-#ifdef HAVE_LIBC_H
+#if defined(HAVE_LIBC_H) && defined(__NeXT__)
 #	include <libc.h>
-#endif /* HAVE_LIBC_H */
+#endif /* HAVE_LIBC_H && __NeXT__ */
 
 #ifdef HAVE_UNISTD_H
 #	include <unistd.h>
@@ -719,7 +719,7 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 
 /*
  * URL related regexs:
- * add TELNET & WAIS (RFC 1738), IMAP (RFC 2192), NFS (RFC 2224)
+ * add TELNET (RFC 4248), WAIS (RFC 4156), IMAP (RFC 2192), NFS (RFC 2224)
  *     LDAP (RFC 2255), POP (RFC 2384)
  * add IPv6 (RFC 2732, RFC 2373) support
  */
