@@ -6,7 +6,7 @@
 # digits for minor numbers less than 10. There are unlikely to be
 # that many releases anyway.
 
-PCRE_MAJOR=4
-PCRE_MINOR=3
-PCRE_DATE=21-May-2003
+PCRE_MAJOR=6
+PCRE_MINOR=4
+PCRE_DATE=05-Sep-2005
 PCRE_VERSION=${PCRE_MAJOR}.${PCRE_MINOR}
