@@ -3,10 +3,10 @@
  *  Module    : charset.c
  *  Author    : M. Kuhn, T. Burmester
  *  Created   : 1993-12-10
- *  Updated   : 2003-01-16
+ *  Updated   : 2006-02-21
  *  Notes     : ISO to ascii charset conversion routines
  *
- * Copyright (c) 1993-2003 Markus Kuhn <mgk25@cl.cam.ac.uk>
+ * Copyright (c) 1993-2006 Markus Kuhn <mgk25@cl.cam.ac.uk>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -255,7 +255,7 @@ convert_tex2iso(
 	char *from,
 	char *to)
 {
-	const char * tex_to[TEX_SUBST];
+	const char *tex_to[TEX_SUBST];
 	int i;
 	size_t spaces = 0; /* spaces to add */
 	size_t len, col = 0;	/* length of from, col counter */
@@ -309,7 +309,7 @@ convert_tex2iso(
 			subst_len = strlen(tex_from[i]);
 			if (!strncmp(from + col, tex_from[i], subst_len)) {
 				strcat(to, tex_to[i]);
-				spaces += subst_len - 1;
+				spaces += subst_len - strlen(tex_to[i]);
 				col += subst_len - 1;
 				ex = TRUE;
 			}
@@ -371,25 +371,29 @@ is_art_tex_encoded(
 
 /*
  * Replace all non printable characters by '?'
- *
- * NOTES: don't make wc a wint_t as libutf8 (at least version 0.8)
- *        sometimes fails to propper convert (wchar_t) 0 to (wint_t) 0
- *        and thus loop termination fails.
  */
 char *
 convert_to_printable(
 	char *buf)
 {
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
-	wchar_t wbuffer[LEN];
-	char buffer[LEN];
+	char *buffer;
+	wchar_t *wbuffer;
+	size_t len = strlen(buf) + 1;
 
-	if (mbstowcs(wbuffer, buf, LEN - 1) != (size_t) (-1)) {
+	if (IS_LOCAL_CHARSET("UTF-8"))
+		utf8_valid(buf);
+
+	if ((wbuffer = char2wchar_t(buf)) != NULL) {
 		wconvert_to_printable(wbuffer);
 
-		wcstombs(buffer, wbuffer, LEN - 1);
-		buffer[LEN - 1] = '\0';
-		strcpy(buf, (const char *) buffer);
+		if ((buffer = wchar_t2char(wbuffer)) != NULL) {
+			strncpy(buf, buffer, len);
+			buf[len - 1] = '\0';
+
+			free(buffer);
+		}
+		free(wbuffer);
 	}
 #else
 	unsigned char *c;
@@ -404,6 +408,11 @@ convert_to_printable(
 
 
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
+/*
+ * NOTES: don't make wc a wint_t as libutf8 (at least version 0.8)
+ *        sometimes fails to propper convert (wchar_t) 0 to (wint_t) 0
+ *        and thus loop termination fails.
+ */
 wchar_t *
 wconvert_to_printable(
 	wchar_t *wbuf)
@@ -429,24 +438,26 @@ wconvert_to_printable(
  *        sometimes fails to propper convert (wchar_t) 0 to (wint_t) 0
  *        and thus loop termination fails.
  */
-void
+char *
 convert_body2printable(
 	char *buf)
 {
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
-	char buffer[LEN];
-	wchar_t *wc;
-	wchar_t wbuffer[LEN];
+	char *buffer;
+	wchar_t *wc, *wbuffer;
+	size_t len = strlen(buf) + 1;
 
-	if (mbstowcs(wbuffer, buf, LEN - 1) != (size_t) (-1)) {
+	if ((wbuffer = char2wchar_t(buf)) != NULL) {
 		for (wc = wbuffer; *wc; wc++) {
 			if (!(iswprint((wint_t) *wc) || *wc == (wchar_t) 8 || *wc == (wchar_t) 9 || *wc == (wchar_t) 10 || *wc == (wchar_t) 12 || *wc == (wchar_t) 13 || (IS_LOCAL_CHARSET("Big5") && *wc == (wchar_t) 27)))
 				*wc = (wchar_t) '?';
 		}
-
-		wcstombs(buffer, wbuffer, LEN - 1);
-		buffer[LEN - 1] = '\0';
-		strcpy(buf, (const char *) buffer);
+		if ((buffer = wchar_t2char(wbuffer)) != NULL) {
+			strncpy(buf, buffer, len);
+			buf[len - 1] = '\0';
+			free(buffer);
+		}
+		free(wbuffer);
 	}
 #else
 	unsigned char *c;
@@ -456,4 +467,5 @@ convert_body2printable(
 			*c = '?';
 	}
 #endif /* MULTIBYTE_ABLE && !NO_LOCALE */
+	return buf;
 }
