@@ -5,13 +5,13 @@
  *  Author    : Roland Rosenfeld <roland@spinnaker.rhein.de>
  *              Giuseppe De Marco <gdm@rebel.net> (light-colors)
  *              Julien Oster <fuzzy@cu8.cum.de> (word highlighting)
- *              T.Dickey <dickey@herndon4.his.com> (curses support)
+ *              T.Dickey <dickey@invisible-island.net> (curses support)
  *  Created   : 1995-06-02
- *  Updated   : 1996-12-15
+ *  Updated   : 2004-06-07
  *  Notes     : This are the basic function for ansi-color
  *              and word highlighting
  *
- * Copyright (c) 1995-2003 Roland Rosenfeld <roland@spinnaker.rhein.de>
+ * Copyright (c) 1995-2006 Roland Rosenfeld <roland@spinnaker.rhein.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -22,10 +22,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *    This product includes software developed by Roland Rosenfeld.
- * 4. The name of the author may not be used to endorse or promote
+ * 3. The name of the author may not be used to endorse or promote
  *    products derived from this software without specific prior written
  *    permission.
  *
@@ -59,7 +56,9 @@
 int default_fcol = 7;
 int default_bcol = 0;
 
-static int current_fcol = 7;
+#	ifdef USE_CURSES
+	static int current_fcol = 7;
+#	endif /* USE_CURSES */
 static int current_bcol = 0;
 
 
@@ -100,7 +99,8 @@ set_colors(
 
 		TRACE(("set_colors(%d, %d)", fcolor, bcolor));
 
-		/* fcolor/bcolor may be negative, if we're using ncurses
+		/*
+		 * fcolor/bcolor may be negative, if we're using ncurses
 		 * function use_default_colors().
 		 */
 		if (fcolor > COLORS - 1) {
@@ -124,7 +124,7 @@ set_colors(
 			if (found)
 				pair = p->pair;
 			else if (++nextpair < COLOR_PAIRS) {
-				p = my_malloc(sizeof(struct LIST));
+				p = my_malloc(sizeof(struct LIST)); /* TODO: plug mem leak */
 				p->fg = fcolor;
 				p->bg = bcolor;
 				p->pair = pair = nextpair;
@@ -154,11 +154,12 @@ void
 fcol(
 	int color)
 {
-	TRACE(("fcol(%d) %s", color, txt_colors[color-MIN_COLOR]));
+	TRACE(("fcol(%d) %s", color, txt_colors[color - MIN_COLOR]));
 	if (use_color) {
 		if (color >= MIN_COLOR && color <= MAX_COLOR) {
 #	ifdef USE_CURSES
 			set_colors(color, current_bcol);
+			current_fcol = color;
 #	else
 			int bold;
 			if (color < 0)
@@ -168,7 +169,6 @@ fcol(
 			if (!bold)
 				bcol(current_bcol);
 #	endif /* USE_CURSES */
-			current_fcol = color;
 		}
 	}
 #	ifdef USE_CURSES
@@ -183,7 +183,7 @@ void
 bcol(
 	int color)
 {
-	TRACE(("bcol(%d) %s", color, txt_colors[color-MIN_COLOR]));
+	TRACE(("bcol(%d) %s", color, txt_colors[color - MIN_COLOR]));
 	if (use_color) {
 		if (color >= MIN_COLOR && color <= MAX_BACKCOLOR) {
 #	ifdef USE_CURSES
@@ -211,7 +211,8 @@ bcol(
 void
 draw_pager_line(
 	const char *str,
-	int flags)
+	int flags,
+	t_bool raw_data)
 {
 #ifdef HAVE_COLOR
 
@@ -233,7 +234,90 @@ draw_pager_line(
 	}
 
 #endif /* HAVE_COLOR */
-	my_fputs(str, stdout);
+	if (!raw_data) {
+#if defined(HAVE_LIBICUUC) && defined(MULTIBYTE_ABLE) && defined(HAVE_UNICODE_UBIDI_H) && !defined(NO_LOCALE)
+		/*
+		 * BiDi support
+		 */
+		/* don't run it on empty lines and lines containing only one char (which must be an ASCII one) */
+		if (tinrc.render_bidi && IS_LOCAL_CHARSET("UTF-8") && strlen(str) > 1) {
+			char *line;
+			t_bool is_rtl;
+
+			if ((line = render_bidi(str, &is_rtl)) != NULL) {
+				if (is_rtl) { /* RTL */
+					/* determine visual length and pad out so that line is right-aligned */
+					wchar_t *wline;
+
+					if ((wline = char2wchar_t(line)) != NULL) {
+						int visual_len;
+
+						wconvert_to_printable(wline);
+						visual_len = wcswidth(wline, wcslen(wline) + 1);
+						free(wline);
+
+						if (visual_len > 0) {
+							int i;
+
+							for (i = 0; i < cCOLS - visual_len - 1; i++)
+								my_fputc(' ', stdout);
+						}
+						my_fputs(line, stdout);
+					} else /* fallback */
+						my_fputs(line, stdout);
+
+				} else	/* LTR */
+					my_fputs(line, stdout);
+
+				free(line);
+			} else
+				my_fputs(str, stdout);
+		} else
+#endif /* HAVE_LIBICUUC && MULTIBYTE_ABLE && HAVE_UNICODE_UBIDI_H && !NO_LOCALE */
+			my_fputs(str, stdout);
+	} else {
+		/* in RAW-mode (show_all_headers) display non-printable chars as octals */
+		const char *c;
+		char octal[5];
+
+		c = str;
+		while (*c) {
+#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
+			int num_bytes;
+			wchar_t wc;
+
+			num_bytes = mbtowc(&wc, c, MB_CUR_MAX);
+			if (num_bytes != -1 && iswprint(wc)) {
+				my_fputwc((wint_t) wc, stdout);
+				c += num_bytes;
+			}
+#else
+			if (my_isprint((int) *c)) {
+				my_fputc((int) *c, stdout);
+				c++;
+			}
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
+			else if (IS_LOCAL_CHARSET("Big5") && (unsigned char) *c >= 0xa1 &&(unsigned char) *c <= 0xfe && *(c + 1)) {
+				/*
+				 * Big5: ASCII chars are handled by the normal code
+				 * check only for 2-byte chars
+				 * TODO: should we also check if the second byte is also valid?
+				 */
+				my_fputc((int) *c, stdout);
+				c++;
+				my_fputc((int) *c, stdout);
+				c++;
+			} else {
+				/*
+				 * non-printable char
+				 * print as an octal value
+				 */
+				snprintf(octal, sizeof(octal), "\\%03o", (int) *c & 0xff);
+				my_fputs(octal, stdout);
+				c++;
+			}
+		}
+	}
 
 #ifndef USE_CURSES
 	my_fputs(cCRLF, stdout);
