@@ -3,7 +3,7 @@
  *  Module    : curses.c
  *  Author    : D. Taylor & I. Lea
  *  Created   : 1986-01-01
- *  Updated   : 2003-08-03
+ *  Updated   : 2005-04-18
  *  Notes     : This is a screen management library borrowed with permission
  *              from the Elm mail system. This library was hacked to provide
  *              what tin needs.
@@ -38,10 +38,6 @@ t_bool have_linescroll = TRUE;	/* USE_CURSES always allows line scrolling */
 
 #else	/* !USE_CURSES */
 
-#ifdef M_AMIGA
-#	undef BSD
-#endif /* M_AMIGA */
-
 #ifndef ns32000
 #	undef	sinix
 #endif /* !ns32000 */
@@ -61,7 +57,7 @@ t_bool have_linescroll = TRUE;	/* USE_CURSES always allows line scrolling */
 #define DEFAULT_COLUMNS_ON_TERMINAL	80
 
 int cLINES = DEFAULT_LINES_ON_TERMINAL - 1;
-int cCOLS  = DEFAULT_COLUMNS_ON_TERMINAL;
+int cCOLS = DEFAULT_COLUMNS_ON_TERMINAL;
 int _hp_glitch = FALSE;		/* stdout not erased by overwriting on HP terms */
 static int _inraw = FALSE;	/* are we IN rawmode? */
 static int xclicks = FALSE;	/* do we have an xterm? */
@@ -106,7 +102,7 @@ static TTY _raw_tty, _original_tty;
 
 #else	/* FIXME: prune the non-autoconf'd stuff */
 
-#	if (defined(M_AMIGA) && !defined(__SASC)) || defined(COHERENT) || defined(BSD)
+#	if defined(COHERENT) || defined(BSD)
 #		ifdef BSD4_1
 #			include <termio.h>
 #			define USE_TERMIO 1
@@ -115,7 +111,7 @@ static TTY _raw_tty, _original_tty;
 #			define USE_SGTTY 1
 #		endif /* BSD4_1 */
 #	else
-#		if !defined(SYSV) && !defined(M_AMIGA)
+#		if !defined(SYSV)
 #			ifdef MINIX
 #				include <sgtty.h>
 #				define USE_SGTTY 1
@@ -134,24 +130,22 @@ static TTY _raw_tty, _original_tty;
 #					endif /* sinix */
 #				endif /* !QNX42 */
 #			endif /* MINIX */
-#		endif /* !SYSV && !M_AMIGA */
-#	endif /* (M_AMIGA && !__SASC) || COHERENT || BSD */
+#		endif /* !SYSV */
+#	endif /* COHERENT || BSD */
 
 #	ifndef VMS
-#		if (defined(M_AMIGA) && !defined(__SASC)) || defined(BSD) || defined(MINIX)
+#		if defined(BSD) || defined(MINIX)
 #			define USE_SGTTY 1
 struct sgttyb _raw_tty, _original_tty;
 #		else
-#			if !defined(M_AMIGA)
-#				if defined(HAVE_TERMIOS_H) || defined(sinix)
-#					define USE_POSIX_TERMIOS 1
+#			if defined(HAVE_TERMIOS_H) || defined(sinix)
+#				define USE_POSIX_TERMIOS 1
 struct termios _raw_tty, _original_tty;
-#				else
-#					define USE_TERMIO 1
+#			else
+#				define USE_TERMIO 1
 struct termio _raw_tty, _original_tty;
-#				endif /* HAVE_TERMIOS_H || sinix */
-#			endif /* !M_AMIGA */
-#		endif /* (M_AMIGA && !__SASC) || BSD || MINIX */
+#			endif /* HAVE_TERMIOS_H || sinix */
+#		endif /* BSD || MINIX */
 #	endif /* !VMS */
 #endif /* HAVE_CONFIG_H */
 
@@ -159,12 +153,11 @@ struct termio _raw_tty, _original_tty;
 #	define USE_SGTTY 0
 #endif /* !USE_SGTTY */
 
-#ifndef USE_TERMIO
-#	define USE_TERMIO 0
-#endif /* !USE_TERMIO */
-
 #ifndef USE_POSIX_TERMIOS
 #	define USE_POSIX_TERMIOS 0
+#	ifndef USE_TERMIO
+#		define USE_TERMIO 0
+#	endif /* !USE_TERMIO */
 #endif /* !USE_POSIX_TERMIOS */
 
 static char *_clearscreen, *_moveto, *_cleartoeoln, *_cleartoeos,
@@ -174,10 +167,6 @@ static char *_clearscreen, *_moveto, *_cleartoeoln, *_cleartoeos,
 			*_scrollregion, *_scrollfwd, *_scrollback,
 			*_reset, *_reversevideo, *_blink, *_dim, *_bold;
 
-#ifdef M_AMIGA
-static char *_getwinsize;
-#endif /* M_AMIGA */
-
 static int _columns, _line, _lines;
 
 #ifdef M_UNIX
@@ -213,9 +202,6 @@ static int _columns, _line, _lines;
 static int input_pending(int delay);
 static void ScreenSize(int *num_lines, int *num_columns);
 static void xclick(int state);
-#if !defined(VMS) && defined(M_AMIGA)
-	static int AmiReadCh(int getscrsize);
-#endif /* !VMS && M_AMIGA */
 
 
 /*
@@ -349,9 +335,9 @@ get_termcaps(
 	for (n = 0; n < ARRAY_SIZE(table); n++) {
 		*(table[n].value) = TGETSTR(table[n].capname, &ptr);
 	}
-	_lines          = TGETNUM(dCAPNAME("li", "lines"));
-	_columns        = TGETNUM(dCAPNAME("co", "cols"));
-	_hp_glitch      = TGETFLAG(dCAPNAME("xs", "xhp"));
+	_lines = TGETNUM(dCAPNAME("li", "lines"));
+	_columns = TGETNUM(dCAPNAME("co", "cols"));
+	_hp_glitch = TGETFLAG(dCAPNAME("xs", "xhp"));
 
 #	if defined(USE_TERMCAP) && defined(HAVE_EXTERN_TCAP_PC)
 	t = TGETSTR(CAPNAME("pc", "pad"), &p);
@@ -361,10 +347,10 @@ get_termcaps(
 
 	if (STRCMPEQ(the_termname, "xterm")) {
 		static char x_init[] = "\033[?9h";
-		static char x_end[]  = "\033[?9l";
+		static char x_end[] = "\033[?9l";
 		xclicks = TRUE;
-		_xclickinit	= x_init;
-		_xclickend	= x_end;
+		_xclickinit = x_init;
+		_xclickend = x_end;
 	}
 
 	if (NO_CAP(_clearscreen)) {
@@ -432,64 +418,38 @@ InitScreen(
 	 * we're going to assume a terminal here...
 	 */
 
-	_clearscreen	= "\033[1;1H\033[J";
-	_moveto		= "\033[%d;%dH";	/* not a termcap string! */
-	_cleartoeoln	= "\033[K";
-	_setinverse	= "\033[7m";
-	_clearinverse	= "\033[0m";
-	_setunderline	= "\033[4m";
-	_clearunderline	= "\033[0m";
-	_keypadlocal	= "";
-	_keypadxmit	= "";
-#	ifdef M_AMIGA
-	_terminalinit	= "\033[12{\033[0 p";
-	_terminalend	= "\033[12}\033[ p";
-	_cursoron	= "\033[ p";
-	_cursoroff	= "\033[0 p";
-	_cleartoeos	= "\033[J";
-	_getwinsize	= "\2330 q";
-#	endif /* M_AMIGA */
+	_clearscreen = "\033[1;1H\033[J";
+	_moveto = "\033[%d;%dH";	/* not a termcap string! */
+	_cleartoeoln = "\033[K";
+	_setinverse = "\033[7m";
+	_clearinverse = "\033[0m";
+	_setunderline = "\033[4m";
+	_clearunderline = "\033[0m";
+	_keypadlocal = "";
+	_keypadxmit = "";
 #	ifdef VMS
-	_cleartoeos	= "\033[J";
-	_terminalinit	= NULL;
-	_terminalend	= "";
+	_cleartoeos = "\033[J";
+	_terminalinit = NULL;
+	_terminalend = "";
 #	endif /* VMS */
 	/* needed for word highlighting */
-	_reset		= "\033[0m";
-	_reversevideo	= "\033[7m";
-	_blink		= "\033[5m";
-	_dim		= "\033[2m";
-	_bold		= "\033[1m";
+	_reset = "\033[0m";
+	_reversevideo = "\033[7m";
+	_blink = "\033[5m";
+	_dim = "\033[2m";
+	_bold = "\033[1m";
 
 	_lines = _columns = -1;
 
-	/*
-	 * Get lines and columns from environment settings - useful when
-	 * you're using something other than an Amiga window
-	 */
-
-	if ((ptr = getenv("LINES")) != 0) {
+	if ((ptr = getenv("LINES")) != 0)
 		_lines = atol(ptr);
-	}
-	if ((ptr = getenv("COLUMNS")) != 0) {
+
+	if ((ptr = getenv("COLUMNS")) != 0)
 		_columns = atol(ptr);
-	}
 
 	/*
 	 * If that failed, try get a response from the console itself
 	 */
-#	ifdef M_AMIGA
-	if (_lines == -1 || _columns == -1) {
-		_lines = DEFAULT_LINES_ON_TERMINAL;
-		_columns = DEFAULT_COLUMNS_ON_TERMINAL;
-	} else {
-		_terminalinit = NULL;		/* don't do fancy things on a non-amiga console */
-		_terminalend = NULL;
-		_cursoroff = NULL;
-		_cursoron = NULL;
-		_getwinsize = NULL;
-	}
-#	endif /* M_AMIGA */
 #	ifdef VMS /* moved from below InitWin() M.St. 22.01.98 */
 	{
 		int input_chan, status;
@@ -547,7 +507,7 @@ InitScreen(
 			xclicks = TRUE;
 			if (!eightbit) {
 				_xclickinit = "\033[?9h";
-				_xclickend  = "\033[?9l";
+				_xclickend = "\033[?9l";
 			}
 #			if 0
 			else {
@@ -674,7 +634,7 @@ MoveCursor(
 	char stuff[12];
 
 	if (_moveto) {
-		sprintf(stuff, _moveto, row + 1, col + 1);
+		snprintf(stuff, sizeof(stuff), _moveto, row + 1, col + 1);
 		tputs(stuff, 1, outchar);
 		my_flush();
 		_line = row + 1;
@@ -856,10 +816,6 @@ Raw(
 		_inraw = 1;
 	}
 #else
-#	if defined(M_AMIGA) && defined(__SASC)
-	_inraw = state;
-	rawcon(state);
-#	else
 	if (!state && _inraw) {
 		SET_TTY(&_original_tty);
 		_inraw = 0;
@@ -869,9 +825,6 @@ Raw(
 #		if USE_SGTTY
 		_raw_tty.sg_flags &= ~(ECHO | CRMOD);	/* echo off */
 		_raw_tty.sg_flags |= CBREAK;		/* raw on */
-#			ifdef M_AMIGA
-		_raw_tty.sg_flags |= RAW; /* Manx-C 5.2 does not support CBREAK */
-#			endif /* M_AMIGA */
 #		else
 #			ifdef __FreeBSD__
 		cfmakeraw(&_raw_tty);
@@ -885,130 +838,10 @@ Raw(
 		SET_TTY(&_raw_tty);
 		_inraw = 1;
 	}
-#	endif /* M_AMIGA && __SASC */
 #endif /* !VMS */
 }
 
 
-/*
- * read a character with Raw mode set!
- */
-
-#ifndef VMS
-#	ifdef M_AMIGA
-#		include <sprof.h>
-
-static int new_lines, new_columns;
-
-static int
-AmiReadCh(
-	int getscrsize)
-{
-	int result;
-	static int buflen = 0, bufp = 0;
-	static unsigned char buf[128];
-	unsigned char ch;
-
-	while (getscrsize || !buflen) {
-PROFILE_OFF();
-		result = read(0, (char *) &buf[buflen], 1);
-PROFILE_ON();
-		if (result <= 0) return EOF;
-		buflen++;
-		if (buf[bufp] == KEY_PREFIX) {
-			do {
-				result = read(0, (char *) &buf[buflen], 1);
-				if (result <= 0) return EOF;
-			} while (buf[buflen++] < 0x40);
-
-			switch (buf[buflen - 1]) {
-				char *ptr;
-				long class;
-
-				case 'r':		/* Window bounds report */
-					ptr = (char *) &buf[bufp + 1];
-					strtol(ptr, &ptr, 10);
-					ptr++;
-					strtol(ptr, &ptr, 10);
-					ptr++;
-					new_lines = strtol(ptr, &ptr, 10);
-					ptr++;
-					new_columns = strtol(ptr, &ptr, 10);
-					buflen = bufp;
-					if (getscrsize)
-						return 0;
-					break;
-
-				case '|':		/* Raw Input Events */
-					ptr = (char *) &buf[bufp + 1];
-					class = strtol(ptr, &ptr, 10);
-					ptr++;
-					switch (class) {
-						int x, y;
-
-						case 12:	/* Window resized */
-							buflen = bufp; /* Must do this before raise() */
-							raise(SIGWINCH);
-							break;
-#			ifdef notdef
-						case 2:	/* Mouse event */
-					/*
-					 * At this point we know what button was pressed
-					 * but we don't really know where the mouse is.
-					 * The <x> and <y> parameters don't help.
-					 * Perhaps looking directly in the window's structure
-					 * is the easiest thing to do (after finding out where
-					 * the window's structure is! Sending an ACTION_INFO
-					 * packet to the handler gives us this. I don't know
-					 * if there is an easier way.
-					 */
-							buflen = bufp;
-							break;
-#			endif /* notdef */
-						default:
-							buflen = bufp;
-							break;
-					}
-					break;
-
-				default:
-					break;
-			}
-		}
-	}
-
-	ch = buf[bufp++];
-	if (bufp >= buflen)
-		buflen = bufp = 0;
-	return ch;
-}
-
-
-int
-ReadCh(
-	void)
-{
-	return AmiReadCh(0);
-}
-
-
-void
-AmiGetWinSize(
-	int *lines,
-	int *columns)
-{
-	if (_getwinsize) {
-		tputs(_getwinsize, 1, outchar);	/* identify yourself */
-		my_flush();
-		AmiReadCh(1);		/* Look for the identification */
-		*lines = new_lines;
-		*columns = new_columns;
-	}
-}
-
-#	endif /* M_AMIGA */
-#endif /* !VMS */
-
 /*
  *  output a character. From tputs... (Note: this CANNOT be a macro!)
  */
@@ -1106,13 +939,13 @@ highlight_string(
 	 */
 	if (col > 0) {
 		char tmp[LEN];
-		wchar_t wtmp[LEN];
+		wchar_t *wtmp;
 
 		my_strncpy(tmp, &(screen[row].col[0]), sizeof(tmp) - 1);
 		tmp[col] = '\0';
-		if (mbstowcs(wtmp, tmp, ARRAY_SIZE(wtmp) - 1) != (size_t) -1) {
-			wtmp[ARRAY_SIZE(wtmp) - 1] = (wchar_t) '\0';
-			col = wcswidth(wtmp, ARRAY_SIZE(wtmp));
+		if ((wtmp = char2wchar_t(tmp)) != NULL) {
+			col = wcswidth(wtmp, wcslen(wtmp) + 1);
+			free(wtmp);
 		}
 	}
 #endif /* MULTIBYTE_ABLE && !NO_LOCALE */
@@ -1146,7 +979,7 @@ word_highlight_string(
 	int byte_offset = col;
 	int wsize = size;
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
-	wchar_t wtmp[LEN];
+	wchar_t *wtmp;
 #endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 
 	attributes[0] = _reset;	/* Normal */
@@ -1169,14 +1002,14 @@ word_highlight_string(
 		char tmp[LEN];
 		my_strncpy(tmp, &(screen[row].col[0]), sizeof(tmp) - 1);
 		tmp[byte_offset] = '\0';
-		if (mbstowcs(wtmp, tmp, ARRAY_SIZE(wtmp) - 1) != (size_t) -1) {
-			wtmp[ARRAY_SIZE(wtmp) - 1] = (wchar_t) '\0';
-			col = wcswidth(wtmp, ARRAY_SIZE(wtmp));
+		if ((wtmp = char2wchar_t(tmp)) != NULL) {
+			col = wcswidth(wtmp, wcslen(wtmp) + 1);
+			free(wtmp);
 		}
 	}
-	if (mbstowcs(wtmp, output, ARRAY_SIZE(wtmp) - 1) != (size_t) -1) {
-		wtmp[ARRAY_SIZE(wtmp) - 1] = (wchar_t) '\0';
-		wsize = wcswidth(wtmp, ARRAY_SIZE(wtmp));
+	if ((wtmp = char2wchar_t(output)) != NULL) {
+		wsize = wcswidth(wtmp, wcslen(wtmp) + 1);
+		free(wtmp);
 	}
 #endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 
@@ -1258,10 +1091,6 @@ input_pending(
 
 #else
 
-#	ifdef M_AMIGA
-	return (WaitForChar(Input(), 1000 * delay) == DOSTRUE) ? TRUE : FALSE;
-#	endif /* M_AMIGA */
-
 #	ifdef HAVE_SELECT
 	int fd = STDIN_FILENO;
 	fd_set fdread;
@@ -1325,10 +1154,6 @@ get_arrow_key(
 		&& i < ((VT_ESCAPE_TIMEOUT * 1000) / SECOND_CHARACTER_DELAY))
 
 #	ifndef VMS
-#		ifdef M_AMIGA
-	if (WaitForChar(Input(), 1000) == DOSTRUE)
-		return prech;
-#		else	/* !M_AMIGA */
 	if (!input_pending(0)) {
 #			ifdef HAVE_USLEEP
 		int i = 0;
@@ -1365,7 +1190,6 @@ get_arrow_key(
 		if (!input_pending(0))
 			return prech;
 	}
-#		endif /* M_AMIGA */
 #	endif /* !VMS */
 	ch = ReadCh();
 	if (ch == '[' || ch == 'O')
@@ -1404,11 +1228,7 @@ get_arrow_key(
 #	ifdef QNX42
 		case 0xA2:
 #	endif /* QNX42 */
-#	ifdef M_AMIGA
-			return KEYMAP_PAGE_DOWN;
-#	else
 			return KEYMAP_PAGE_UP;
-#	endif /* M_AMIGA */
 
 		case 'G':		/* ansi  PgDn */
 		case 'U':		/* at386 PgDn */
@@ -1416,11 +1236,7 @@ get_arrow_key(
 #	ifdef QNX42
 		case 0xAA:
 #	endif /* QNX42 */
-#	ifdef M_AMIGA
-			return KEYMAP_PAGE_UP;
-#	else
 			return KEYMAP_PAGE_DOWN;
-#	endif /* M_AMIGA */
 
 		case 'H':		/* at386 Home */
 #	ifdef QNX42
@@ -1491,7 +1307,7 @@ ReadCh(
 	int result;
 #	ifndef READ_CHAR_HACK
 	char ch;
-#	endif /* READ_CHAR_HACK */
+#	endif /* !READ_CHAR_HACK */
 
 	fflush(stdout);
 #	ifdef READ_CHAR_HACK
