@@ -3,7 +3,7 @@
  *  Module    : getline.c
  *  Author    : Chris Thewalt & Iain Lea
  *  Created   : 1991-11-09
- *  Updated   : 2003-08-03
+ *  Updated   : 2004-07-02
  *  Notes     : emacs style line editing input package.
  *  Copyright : (c) Copyright 1991-99 by Chris Thewalt & Iain Lea
  *              Permission to use, copy, modify, and distribute this
@@ -23,7 +23,6 @@
 #endif /* !TCURSES_H */
 
 #define BUF_SIZE	1024
-#define SCROLL		30
 #define TABSIZE		4
 
 #define CTRL_A	'\001'
@@ -66,7 +65,6 @@ static t_bool is_passwd;
 #endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 static void gl_del(int loc);
 static void gl_fixup(int change, int cursor);
-static void gl_redraw(void);
 static void gl_newline(int w);
 static void gl_kill(void);
 static void gl_kill_back_word(void);
@@ -100,6 +98,8 @@ tin_getline(
 	char *buf = gl_buf;
 #endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 
+	input_context = cGetline;
+
 	is_passwd = passwd;
 
 	set_xclick_off();
@@ -135,12 +135,12 @@ tin_getline(
 
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
 	if (str != NULL) {
-		wchar_t wbuf[LEN];
+		wchar_t *wbuf;
 
-		if (mbstowcs(wbuf, str, ARRAY_SIZE(wbuf) - 1) != (size_t) -1) {
-			wbuf[ARRAY_SIZE(wbuf) - 1] = (wchar_t) '\0';
+		if ((wbuf = char2wchar_t(str)) != NULL) {
 			for (i = 0; wbuf[i]; i++)
 				gl_addwchar(wbuf[i]);
+			free(wbuf);
 		}
 	}
 
@@ -227,7 +227,8 @@ tin_getline(
 							break;
 
 						default:
-							return (char *) 0;
+							input_context = cNone;
+							return NULL;
 					}
 					break;
 
@@ -237,6 +238,7 @@ tin_getline(
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
 					wcstombs(buf, gl_buf, BUF_SIZE - 1);
 #endif /* MULTIBYTE_ABLE && !NO_LOCALE */
+					input_context = cNone;
 					return buf;
 
 				case CTRL_A:
@@ -254,6 +256,7 @@ tin_getline(
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
 						wcstombs(buf, gl_buf, BUF_SIZE - 1);
 #endif /* MULTIBYTE_ABLE && !NO_LOCALE */
+						input_context = cNone;
 						return buf;
 					} else
 						gl_del(0);
@@ -314,6 +317,7 @@ tin_getline(
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
 	wcstombs(buf, gl_buf, BUF_SIZE - 1);
 #endif /* MULTIBYTE_ABLE && !NO_LOCALE */
+	input_context = cNone;
 	return buf;
 }
 
@@ -493,15 +497,21 @@ gl_kill_back_word(
 /*
  * emit a newline, reset and redraw prompt and current input line
  */
-static void
+void
 gl_redraw(
 	void)
 {
-	if (gl_init_done == -1) {
+	if (gl_init_done == -1) {	/* terminal */
 		my_fputc('\n', stdout);
 		my_fputs(gl_prompt, stdout);
 		gl_pos = 0;
 		gl_fixup(0, BUF_SIZE);
+	} else if (gl_init_done == 0) {	/* screen */
+		clear_message();
+		my_fputs(gl_prompt, stdout);
+		gl_pos = 0;
+		gl_fixup(0, BUF_SIZE);
+		cursoron();
 	}
 }
 
@@ -529,6 +539,8 @@ gl_fixup(
 	int new_shift;		/* value of shift based on cursor */
 	int extra;		/* adjusts when shift (scroll) happens */
 	int i;
+	/* FIXME: there are some small problems if SCROLL >= gl_width - 2 */
+	int SCROLL = MIN(30, gl_width - 3);
 
 	if (change == -1 && cursor == 0 && gl_buf[0] == 0) {	/* reset */
 		gl_shift = off_right = off_left = 0;
@@ -667,24 +679,18 @@ hist_add(
 {
 	char *p;
 	char *tmp;
-#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
-	int size = wcstombs(NULL, gl_buf, 0);
-
-	tmp = my_malloc(size + 1);
-	if (wcstombs(tmp, gl_buf, size) == (size_t) -1) {
-		/* conversation failed */
-		free(tmp);
-		return;
-	} else
-		tmp[size] = '\0';
-#else
-	tmp = my_strdup(gl_buf);
-#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
-	p = tmp;
 
 	if (w == HIST_NONE)
 		return;
 
+#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
+	if ((tmp = wchar_t2char(gl_buf)) == NULL)
+		return;
+#else
+	tmp = my_strdup(gl_buf);
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
+
+	p = tmp;
 	while (*p == ' ' || *p == '\t')		/* only save nonblank line */
 		p++;
 
