@@ -3,9 +3,9 @@
  *  Module    : header.c
  *  Author    : Urs Janssen <urs@tin.org>
  *  Created   : 1997-03-10
- *  Updated   : 2005-07-09
+ *  Updated   : 2006-01-10
  *
- * Copyright (c) 1997-2005 Urs Janssen <urs@tin.org>
+ * Copyright (c) 1997-2006 Urs Janssen <urs@tin.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -157,13 +157,13 @@ get_fqdn(
 		in_addr_t addr = inet_addr(name);
 
 		if ((hp = gethostbyaddr((char *) &addr, 4, AF_INET)))
-			in.s_addr = (*hp->h_addr);
+			in.s_addr = (*hp->h_addr_list[0]);
 		return (hp && strchr(hp->h_name, '.') ? hp->h_name : inet_ntoa(in));
 	}
 #	endif /* HAVE_INET_ADDR */
 	if ((hp = gethostbyname(name)) && !strchr(hp->h_name, '.'))
-		if ((hp = gethostbyaddr(hp->h_addr, hp->h_length, hp->h_addrtype)))
-			in.s_addr = (*hp->h_addr);
+		if ((hp = gethostbyaddr(hp->h_addr_list[0], hp->h_length, hp->h_addrtype)))
+			in.s_addr = (*hp->h_addr_list[0]);
 
 	snprintf(fqdn, sizeof(fqdn), "%s", hp
 		? strchr(hp->h_name, '.')
