@@ -3,10 +3,10 @@
  *  Module    : inews.c
  *  Author    : I. Lea
  *  Created   : 1992-03-17
- *  Updated   : 2003-05-01
+ *  Updated   : 2005-02-12
  *  Notes     : NNTP built in version of inews
  *
- * Copyright (c) 1991-2003 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1991-2006 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -83,6 +83,8 @@
 
 /*
  * Submit an article using the NNTP POST command
+ *
+ * TODO: remove mailheaders (To, Cc, Bcc, ...)?
  */
 #ifdef NNTP_INEWS
 static t_bool
@@ -391,12 +393,14 @@ submit_news_file(
 {
 	char buf[PATH_LEN];
 	char *cp = buf;
+	char *fcc;
 	t_bool ret_code;
 	t_bool ismail = FALSE;
 
 	a_message_id[0] = '\0';
 
-	checknadd_headers(name);
+	fcc = checknadd_headers(name);
+	FreeIfNeeded(fcc); /* we don't use it at the moment */
 
 	rfc15211522_encode(name, txt_mime_encodings[tinrc.post_mime_encoding], group, tinrc.post_8bit_header, ismail);
 
@@ -426,10 +430,10 @@ submit_news_file(
 
 #ifdef NNTP_INEWS
 			if (!ret_code && read_news_via_nntp && !read_saved_news && 0 != strcasecmp(tinrc.inews_prog, INTERNAL_CMD)) {
-				if (prompt_yn(cLINES, _(txt_post_via_builtin_inews), TRUE)) {
+				if (prompt_yn(_(txt_post_via_builtin_inews), TRUE)) {
 					ret_code = submit_inews(name, group, a_message_id);
 					if (ret_code) {
-						if (prompt_yn(cLINES, _(txt_post_via_builtin_inews_only), TRUE) == 1)
+						if (prompt_yn(_(txt_post_via_builtin_inews_only), TRUE) == 1)
 							strcpy(tinrc.inews_prog, INTERNAL_CMD);
 					}
 				}
@@ -474,11 +478,11 @@ sender_needed(
 
 	snprintf(sender_line, sizeof(sender_line), "Sender: %s", sender);
 
-#ifdef CHARSET_CONVERSION
+#	ifdef CHARSET_CONVERSION
 	p = rfc1522_encode(sender_line, group ? txt_mime_charsets[group->attribute->mm_network_charset] : txt_mime_charsets[tinrc.mm_network_charset], FALSE);
-#else
+#	else
 	p = rfc1522_encode(sender_line, tinrc.mm_charset, FALSE);
-#endif /* CHARSET_CONVERSION */
+#	endif /* CHARSET_CONVERSION */
 	if (GNKSA_OK != gnksa_do_check_from(p + 8, sender_addr, sender_name)) {
 		free(p);
 		return -2;
