@@ -3,10 +3,10 @@
  *  Module    : mail.c
  *  Author    : I. Lea
  *  Created   : 1992-10-02
- *  Updated   : 2005-08-14
+ *  Updated   : 2006-01-19
  *  Notes     : Mail handling routines for creating pseudo newsgroups
  *
- * Copyright (c) 1992-2005 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1992-2006 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -369,7 +369,7 @@ read_groups_descriptions(
 			space = strlen(ptr) + 1;
 			groupname = my_malloc(space);
 		} else {
-			while (strlen(ptr) > space) { /* realloc needed? */
+			while (space < strlen(ptr) + 1) { /* realloc needed? */
 				space <<= 1; /* double size */
 				groupname = my_realloc(groupname, space);
 			}
