@@ -3,10 +3,10 @@
  *  Module    : misc.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2005-08-14
+ *  Updated   : 2006-04-06
  *  Notes     :
  *
- * Copyright (c) 1991-2005 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2006 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -912,7 +912,7 @@ dir_name(
  *
  * TODO: why not cache the mailbox_name?
  */
-#define MAILDIR_NEW	"/new"
+#define MAILDIR_NEW	"new"
 t_bool
 mail_check(
 	void)
@@ -928,7 +928,7 @@ mail_check(
 			char *maildir_box;
 			struct dirent *dp;
 
-			maildir_box = my_malloc(strlen(mailbox_name) + strlen(MAILDIR_NEW) + 1);
+			maildir_box = my_malloc(strlen(mailbox_name) + strlen(MAILDIR_NEW) + 2);
 #ifdef VMS
 			joindir(maildir_box, mailbox_name, MAILDIR_NEW);
 #else
