@@ -3,7 +3,7 @@
  *  Module    : nntplib.c
  *  Author    : S. Barber & I. Lea
  *  Created   : 1991-01-12
- *  Updated   : 2005-07-21
+ *  Updated   : 2006-03-05
  *  Notes     : NNTP client routines taken from clientlib.c 1.5.11 (1991-02-10)
  *  Copyright : (c) Copyright 1991-99 by Stan Barber & Iain Lea
  *              Permission is hereby granted to copy, reproduce, redistribute
@@ -363,7 +363,7 @@ get_tcp_socket(
 			t_close(s);
 			return -EHOSTUNREACH;
 		}
-		memcpy((char *) &sock_in.sin_addr, hp->h_addr, hp->h_length);
+		memcpy((char *) &sock_in.sin_addr, hp->h_addr_list[0], hp->h_length);
 	}
 
 	/*
@@ -458,7 +458,7 @@ get_tcp_socket(
 #			ifdef h_addr
 		def.h_addr_list = alist;
 #			endif /* h_addr */
-		def.h_addr = (char *) &defaddr;
+		def.h_addr_list[0] = (char *) &defaddr;
 		def.h_length = sizeof(struct in_addr);
 		def.h_addrtype = AF_INET;
 		def.h_aliases = 0;
@@ -575,7 +575,7 @@ get_tcp_socket(
 
 	/* And then connect */
 
-	memcpy((char *) &sock_in.sin_addr, hp->h_addr, hp->h_length);
+	memcpy((char *) &sock_in.sin_addr, hp->h_addr_list[0], hp->h_length);
 
 	if (connect(s, (struct sockaddr *) &sock_in, sizeof(sock_in)) < 0) {
 		save_errno = errno;
@@ -1401,10 +1401,28 @@ nntp_open(
 	 * We have to check that we _don't_ get an ERR_COMMAND
 	 */
 	if (nntp_caps.type == NO) {
-		for (i = 0; i < 2; i++) {
-			if (!nntp_command(&xover_cmds[i], ERR_COMMAND, NULL, 0)) {
-				nntp_caps.over_cmd = &xover_cmds[i];
-				break;
+		int j = 0;
+
+		for (i = 0; i < 2 && j >= 0; i++) {
+			j = new_nntp_command(&xover_cmds[i], ERR_NCING, line, sizeof(line));
+			switch (j) {
+				case ERR_COMMAND:
+					break;
+
+				case 224:	/* unexpected multiline ok, e.g.: Synchronet 3.13 NNTP Service 1.92 */
+					nntp_caps.over_cmd = &xover_cmds[i];
+#	ifdef DEBUG
+					debug_nntp(&xover_cmds[i], "skipping data");
+#	endif /* DEBUG */
+					while ((linep = tin_fgets(FAKE_NNTP_FP, FALSE)) != NULL)
+						;
+					j = -1;
+					break;
+
+				default:
+					nntp_caps.over_cmd = &xover_cmds[i];
+					j = -1;
+					break;
 			}
 		}
 	} else {
@@ -1413,8 +1431,25 @@ nntp_open(
 			 * CAPABILITIES/LIST EXTENSIONS didn't mention OVER or XOVER, try
 			 * XOVER
 			 */
-			if (!nntp_command(xover_cmds, ERR_COMMAND, NULL, 0))
-				nntp_caps.over_cmd = xover_cmds;
+			i = new_nntp_command(xover_cmds, ERR_NCING, line, sizeof(line));
+
+			switch (i) {
+				case ERR_COMMAND:
+					break;
+
+				case 224:	/* unexpected multiline ok, e.g.: Synchronet 3.13 NNTP Service 1.92 */
+					nntp_caps.over_cmd = xover_cmds;
+#	ifdef DEBUG
+					debug_nntp(xover_cmds, "skipping data");
+#	endif /* DEBUG */
+					while ((linep = tin_fgets(FAKE_NNTP_FP, FALSE)) != NULL)
+						;
+					break;
+
+				default:
+					nntp_caps.over_cmd = xover_cmds;
+					break;
+			}
 		}
 #	if 0 /* unused */
 		if (!nntp_caps.hdr_cmd) {
@@ -1588,9 +1623,19 @@ get_respcode(
 #	ifdef DEBUG
 		debug_nntp("get_respcode", "authentication");
 #	endif /* DEBUG */
-		strncpy(savebuf, last_put, sizeof(savebuf) - 1);		/* Take copy, as authenticate() will clobber this */
+		strncpy(savebuf, last_put, sizeof(savebuf) - 1);	/* take copy */
 
 		if (authenticate(nntp_server, userid, FALSE)) {
+			if (curr_group != NULL) {
+				DEBUG_IO((stderr, _("Rejoin current group\n")));
+				snprintf(last_put, sizeof(last_put), "GROUP %s", curr_group->name);
+				put_server(last_put);
+				s_gets(last_put, NNTP_STRLEN, nntp_rd_fp);
+#	ifdef DEBUG
+				debug_nntp("<<<", last_put);
+#	endif /* DEBUG */
+				DEBUG_IO((stderr, _("Read (%s)\n"), last_put));
+			}
 			strcpy(last_put, savebuf);
 
 			put_server(last_put);
