@@ -1,12 +1,12 @@
 /*
  *  Project   : tin - a Usenet reader
  *  Module    : trace.c
- *  Author    : Thomas Dickey <dickey@herndon4.his.com>
+ *  Author    : Thomas Dickey <dickey@invisible-island.net>
  *  Created   : 1997-03-22
  *  Updated   : 2001-07-22
  *  Notes     : debugging support via TRACE macro.
  *
- * Copyright (c) 1997-2003 Thomas Dickey <dickey@herndon4.his.com>
+ * Copyright (c) 1997-2006 Thomas Dickey <dickey@invisible-island.net>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -17,10 +17,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *    This product includes software developed by Thomas Dickey.
- * 4. The name of the author may not be used to endorse or promote
+ * 3. The name of the author may not be used to endorse or promote
  *    products derived from this software without specific prior written
  *    permission.
  *
@@ -54,7 +51,7 @@ _tracef(
 	const char *fmt,
 	...)
 {
-	static	FILE	*fp;
+	static FILE *fp;
 	va_list ap;
 
 	if (!fp)
@@ -79,9 +76,9 @@ _tracef(
 char *
 _nc_visbuf(const char *s)
 {
-	return (char *)s;
+	return (char *) s;
 }
-#endif /* NCURSES_VERSION */
+#endif /* !HAVE__TRACEF */
 
 char *
 tin_tracechar(
